@@ -309,7 +309,7 @@ class FOFDataManagerLite(metaclass=Singleton):
 
         # 循环遍历每一天来计算
         shares_list = pd.Series(dtype='float64', name='share')
-        cash_list = pd.Series(dtype='float64', name='cash')
+        other_assets_list = pd.Series(dtype='float64', name='cash')
         fof_nav_list = pd.Series(dtype='float64', name='nav')
         today_fund_mv_list = pd.Series(dtype='float64', name='total_fund_mv')
         today_hedge_mv_list = pd.Series(dtype='float64', name='total_hedge_mv')
@@ -318,7 +318,6 @@ class FOFDataManagerLite(metaclass=Singleton):
         management_fee_list = pd.Series(dtype='float64', name='management_fee')
         custodian_fee_list = pd.Series(dtype='float64', name='custodian_fee')
         administrative_fee_list = pd.Series(dtype='float64', name='administrative_fee')
-        misc_amount_list = pd.Series(dtype='float64', name='misc_amount')
         deposit_interest_list = pd.Series(dtype='float64', name='interest')
         positions_list = pd.Series(dtype='float64', name='position')
         investor_pos_list = []
@@ -341,11 +340,11 @@ class FOFDataManagerLite(metaclass=Singleton):
                 assert not pd.isnull(share_sum), '!!!'
                 share_increased += share_sum
 
-            if cash_list.empty:
-                total_cash = 0
+            if other_assets_list.empty:
+                other_assets = 0
             else:
-                total_cash = cash_list.iat[-1]
-            total_cash += total_amount
+                other_assets = other_assets_list.iat[-1]
+            other_assets += total_amount
 
             try:
                 # 看看当天有没有卖出FOF
@@ -361,10 +360,10 @@ class FOFDataManagerLite(metaclass=Singleton):
                 # 汇总今天所有的赎回资金
                 total_amount_redemp = redemp_data.redemp_confirmed_amount.sum()
                 share_increased += redemp_data.share_changed.sum()
-                total_cash -= total_amount_redemp
+                other_assets -= total_amount_redemp
             finally:
                 share_increased = round(share_increased, 2)
-                total_cash = round(total_cash, 2)
+                other_assets = round(other_assets, 2)
 
             if not math.isclose(total_amount, 0) or not math.isclose(total_amount_redemp, 0):
                 if debug_mode:
@@ -372,7 +371,7 @@ class FOFDataManagerLite(metaclass=Singleton):
 
             # 这个日期之后才正式成立，所以在此之前都不需要处理后续步骤
             if date < self._ESTABLISHED_DATE:
-                cash_list.loc[date] = total_cash
+                other_assets_list.loc[date] = other_assets
                 if not math.isclose(share_increased, 0):
                     shares_list.loc[date] = share_increased
                 continue
@@ -400,9 +399,9 @@ class FOFDataManagerLite(metaclass=Singleton):
                         hedge_fund_mv = self._get_hedge_mv()
                         fund_mv = self._get_fund_mv()
                     if row.event_type == FOFTradeStatus.DIVIDEND_CASH:
-                        total_cash += row.amount
-                assert total_cash >= expenses, f'no enough cash to buy asset!! (date){date} (total cash){total_cash}'
-                total_cash -= expenses
+                        other_assets += row.amount
+                assert other_assets >= expenses, f'no enough cash to buy asset!! (date){date} (total cash){total_cash}'
+                other_assets -= expenses
             except KeyError:
                 pass
 
@@ -419,7 +418,7 @@ class FOFDataManagerLite(metaclass=Singleton):
                                 redemp_share += round(redemp_share * self._monetary_daily_profit.shift(1).at[date, row.fund_id] / 10000, 2)
                             self._fund_pos.loc[self._fund_pos.index >= date, row.fund_id] -= redemp_share
                             fund_mv = self._get_fund_mv()
-                        total_cash += row.amount
+                        other_assets += row.amount
             except KeyError:
                 pass
 
@@ -435,18 +434,16 @@ class FOFDataManagerLite(metaclass=Singleton):
                 management_fee_list.loc[date] = round(net_assets_list.iat[-1] * self._MANAGEMENT_FEE_PER_YEAR / self._get_days_this_year_for_fee(date), 2)
                 custodian_fee_list.loc[date] = round(net_assets_list.iat[-1] * self._CUSTODIAN_FEE_PER_YEAR / self._get_days_this_year_for_fee(date), 2)
                 administrative_fee_list.loc[date] = round(net_assets_list.iat[-1] * self._ADMIN_SERVICE_FEE_PER_YEAR / self._get_days_this_year_for_fee(date), 2)
-                misc_fees = management_fee_list.sum() + custodian_fee_list.sum() + administrative_fee_list.sum()
+                misc_fees = management_fee_list.array[-1] + custodian_fee_list.array[-1] + administrative_fee_list.array[-1]
             else:
                 misc_fees = 0
 
-            cash_list.loc[date] = total_cash
-
             # 应收银行存款利息
-            deposit_interest = round(cash_list.iat[-1] * self._DEPOSIT_INTEREST_PER_YEAR / self._DAYS_PER_YEAR_FOR_INTEREST, 2)
+            deposit_interest = round(other_assets_list.iat[-1] * self._DEPOSIT_INTEREST_PER_YEAR / self._DAYS_PER_YEAR_FOR_INTEREST, 2)
             deposit_interest_list.loc[date] = deposit_interest
 
-            misc_amount = total_cash + deposit_interest_list.sum() - misc_fees
-            misc_amount_list.loc[date] = misc_amount
+            other_assets += (deposit_interest - misc_fees)
+            other_assets_list.loc[date] = other_assets
 
             # 获取持仓中当日公募、私募基金的MV
             if fund_mv is not None:
@@ -468,7 +465,7 @@ class FOFDataManagerLite(metaclass=Singleton):
             today_hedge_mv_list.loc[date] = today_hedge_mv
 
             # 计算净资产
-            today_net_assets = today_fund_mv + today_hedge_mv + misc_amount
+            today_net_assets = today_fund_mv + today_hedge_mv + other_assets
             net_assets_list.loc[date] = today_net_assets
 
             if self._fund_pos is not None:
@@ -516,7 +513,7 @@ class FOFDataManagerLite(metaclass=Singleton):
             fof_nav_list.loc[date] = round(fof_nav, 4)
         # 汇总所有信息
         if debug_mode:
-            total_info = pd.concat([shares_list, cash_list, fof_nav_list, today_fund_mv_list, today_hedge_mv_list, net_assets_list, net_assets_fixed_list, misc_amount_list, deposit_interest_list, positions_list], axis=1).sort_index()
+            total_info = pd.concat([shares_list, other_assets_list, fof_nav_list, today_fund_mv_list, today_hedge_mv_list, net_assets_list, net_assets_fixed_list, deposit_interest_list, positions_list], axis=1).sort_index()
             print(total_info)
         self._fof_nav = pd.concat([fof_nav_list, net_assets_fixed_list, shares_list.cumsum(), deposit_interest_list, management_fee_list, custodian_fee_list, administrative_fee_list], axis=1).sort_index().rename_axis('datetime').reset_index()
         self._fof_nav['share'] = self._fof_nav.share.ffill()
@@ -528,10 +525,11 @@ class FOFDataManagerLite(metaclass=Singleton):
         self._fof_nav['adjusted_nav'] = self._fof_nav.nav
         self._fof_nav['ret'] = self._fof_nav.adjusted_nav / self._fof_nav.adjusted_nav.array[0] - 1
 
-        self._fof_position = pd.concat([positions_list, misc_amount_list.rename('other_assets'), cash_list.rename('deposit_in_bank')], axis=1).rename_axis('datetime').reset_index()
+        self._fof_position = pd.concat([positions_list, other_assets_list.rename('other_assets')], axis=1).rename_axis('datetime').reset_index()
         self._fof_position = self._fof_position[self._fof_position.position.notna()]
         self._fof_position['fof_id'] = fof_id
         self._fof_position['manager_id'] = manager_id
+        self._fof_position['deposit_in_bank'] = None
 
         self._fof_investor_pos = pd.concat(investor_pos_list).rename(columns={'share_changed': 'shares'}).reset_index(drop=True)
         self._fof_investor_pos = self._fof_investor_pos.groupby(by=['fof_id', 'investor_id'], sort=False).sum().reset_index()
