@@ -180,6 +180,9 @@ class HedgeFundDataManager(metaclass=Singleton):
         except KeyError:
             datas['share_after_trans'] = datas['share_changed']
 
+        datas['applied_date'] = datas['datetime']
+        datas['deposited_date'] = datas['datetime']
+
         s = pd.Series(datas).drop(['amount', 'redemp_share'], errors='ignore')
         # TODO: 原子操作下面几步
         if 'id' in datas:
@@ -292,6 +295,8 @@ class HedgeFundDataManager(metaclass=Singleton):
         for k in ('net_asset_value', 'acc_unit_value', 'carry_amount', 'share_changed', 'share_after_trans'):
             datas[k] = float(datas[k])
 
+        datas['applied_date'] = datas['datetime']
+        datas['deposited_date'] = datas['datetime']
         df = pd.Series(datas).to_frame().T
         # TODO: 原子操作下面几步
         if 'id' in datas:
@@ -466,6 +471,14 @@ class HedgeFundDataManager(metaclass=Singleton):
         throw excepion if failed, or return a datetime.date if succeed
         '''
 
+        def _transform_hedge_fund_id(x: str):
+            fund_id = x.split()[0].split('.')[-1]
+            real_fund_id = BasicDataApi().get_hedge_fund_alias(manager_id, fund_id)
+            if real_fund_id is not None and not real_fund_id.empty:
+                return real_fund_id.fund_id.array[0]
+            else:
+                return fund_id
+
         to_parse_date = pd.read_excel(datas, skiprows=3, nrows=1).columns.array[0]
         the_date = re.findall(r'[0-9\-]+', to_parse_date)
         assert the_date, f'parse date failed (info){to_parse_date}'
@@ -491,7 +504,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         mutual_funds['fund_id'] = mutual_funds.fund_id.map(lambda x: x + '!0')
 
         hedge_funds = df.loc[(df.index > '1108.02.01') & (df.index < '1203'), ['数量', '市值.1', '行情']]
-        hedge_funds['fund_id'] = hedge_funds.index.map(lambda x: x.split()[0].split('.')[-1])
+        hedge_funds['fund_id'] = hedge_funds.index.map(_transform_hedge_fund_id)
         hedge_funds = hedge_funds.reset_index(drop=True).rename(columns={
             '数量': 'shares',
             '市值.1': 'mv',
@@ -561,8 +574,8 @@ class HedgeFundDataManager(metaclass=Singleton):
             df = total_df
         if not df.empty:
             print(df)
-            for the_id in df.id.dropna().unique():
-                DerivedDataApi().delete_hedge_fund_custodian_data(id_to_delete=the_id)
+            for row in df.itertuples(index=False):
+                DerivedDataApi().delete_hedge_fund_custodian_data(row.manager_id, row.fof_id, row.datetime)
             df.to_sql(HedgeFundCustodianData.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
         return the_date
 
