@@ -68,10 +68,10 @@ class Order:
         self.source = kwds.get('source')
         self.err_msg = kwds.get('err_msg')
         self.status = kwds.get('status', OrderStatus.NOT_AVAILABLE)
-        
+
     def __str__(self):
         return '<Order id={} ticker={} direction={} ot={} at={} ex={} price={} volume={} source={} err_msg={}>'.format(
-            self.order_id, self.ticker, Direction.read(self.direction), OrderType.read(self.order_type), 
+            self.order_id, self.ticker, Direction.read(self.direction), OrderType.read(self.order_type),
             AssetType.read(self.asset_type), ExchangeID.read(self.exchange), self.price, self.volume, self.source, self.err_msg
         )
 
@@ -96,7 +96,7 @@ class Trade:
                f'price={self.trade_price} volume={self.trade_volume} source={self.source} role={ExecRole.read(self.exec_role)} order_id={self.order_id} time={self.time}>'
 
     def save_trade(self):
-        return {'id'        :   self.trade_id, 
+        return {'id'        :   self.trade_id,
                 'exchange'  :   ExchangeID.read(self.exchange),
                 'ticker'    :   self.ticker,
                 'direction' :   self.direction,
@@ -104,7 +104,7 @@ class Trade:
                 'price'     :   self.trade_price,
                 'volume'    :   self.trade_volume,
                 'time'      :   self.time}
-                
+
 class BacktestKey:
 
     def __init__(self, **kwds):
@@ -174,7 +174,7 @@ class PosItem:
         self.leverage = 0
 
     def get_price_ticker(self):
-        # todo: based on different asset type, 
+        # todo: based on different asset type,
         #   we should use different price
         return self.ticker
 
@@ -199,7 +199,7 @@ class PosItem:
 
     def switch_day(self):
         self.yd_position = self.position
-   
+
     def init_margin(self, pi):
         # 如果当前item是个contract,在此设定这个contract对应的margin
         self.margin = pi
@@ -216,29 +216,29 @@ class PosItem:
 
     def __str__(self):
         return '<PosItem ex={} ticker={} at={} d={} pos={} yd={} trans={} margin={} time={}>'.format(
-            ExchangeID.read(self.exchange), self.ticker, AssetType.read(self.asset_type), 
+            ExchangeID.read(self.exchange), self.ticker, AssetType.read(self.asset_type),
             PosiDirection.read(self.posi_direction), self.position, self.yd_position, self.to_transfer, self.margin, self.time
         )
 
 class PositionInfo:
-    
-    path1 = '../python/config'
-    path2 = './config'
-    try:
-        with open(f'{path1}/fee_rate.yml', 'r') as f:
-            FEE_RATE = yaml.safe_load(f)
-        with open(f'{path1}/contract_sizes.yml', 'r') as f:
-            CONTRACT_SIZES = yaml.safe_load(f)
-    except:
-        with open(f'{path2}/fee_rate.yml', 'r') as f:
-            FEE_RATE = yaml.safe_load(f)
-        with open(f'{path2}/contract_sizes.yml', 'r') as f:
-            CONTRACT_SIZES = yaml.safe_load(f)
+
+    # path1 = '../python/config'
+    # path2 = './config'
+    # try:
+    #     with open(f'{path1}/fee_rate.yml', 'r') as f:
+    #         FEE_RATE = yaml.safe_load(f)
+    #     with open(f'{path1}/contract_sizes.yml', 'r') as f:
+    #         CONTRACT_SIZES = yaml.safe_load(f)
+    # except:
+    #     with open(f'{path2}/fee_rate.yml', 'r') as f:
+    #         FEE_RATE = yaml.safe_load(f)
+    #     with open(f'{path2}/contract_sizes.yml', 'r') as f:
+    #         CONTRACT_SIZES = yaml.safe_load(f)
 
 
     def __init__(self, **kwds):
         # 不同交易所不同同币种手续费率都不一样,因此在这更合适的方法是将手续费率用config形式读入,需要新的交易币种交易方式在此添加即可
-        
+
         self.cash = kwds.get('cash', PosItem())
         _holdings = kwds.get('holdings', [])
         self.holdings = []
@@ -254,7 +254,7 @@ class PositionInfo:
 
     def get_holding(self, ticker, exchange=ExchangeID.NOT_AVAILABLE):
         idx = self._tick_idx.get((ticker, exchange))
-        return None if idx is None else self.holdings[idx] 
+        return None if idx is None else self.holdings[idx]
 
     def create_holding(self, pos_item):
         self.holdings.append(pos_item)
@@ -316,7 +316,7 @@ class PositionInfo:
                     pos.position = -trade.trade_volume
             return
         else:
-            pos = self.get_holding(ticker=trade.ticker, exchange=trade.exchange)    
+            pos = self.get_holding(ticker=trade.ticker, exchange=trade.exchange)
             if pos is None:
                 pos = PosItem(exchange=trade.exchange, ticker=trade.ticker,
                             asset_type=trade.asset_type)
