@@ -89,6 +89,7 @@ class BenchmarkSeiesStatUnit(SeriesStatUnit):
     sortino: float                  # 索提诺
     skew: float                     # 偏度
     kurtosis: float                 # 峰度
+    total_relative_ret: float       # 相对全部收益
 
 @dataclasses.dataclass
 class RetStatUnit:
@@ -278,6 +279,7 @@ class Calculator:
             skew=res['skew'],
             kurtosis=res['kurtosis'],
             cumu_ret=res['cumu_ret'],
+            total_relative_ret=res['total_relative_ret'],
         )
 
     @staticmethod
