@@ -12,6 +12,7 @@ from statsmodels.tsa.ar_model import AutoReg
 from scipy.stats import kurtosis, skew
 from decimal import Decimal, ROUND_HALF_UP, Context
 from pandas.tseries.offsets import DateOffset
+from ..data.api.basic import BasicDataApi
 
 class CalculatorBase:
 
@@ -364,6 +365,9 @@ class CalculatorBase:
                 period_6m = period_1m * 6
                 period_1y = CalculatorBase.TRADING_DAYS_PER_YEAR
                 risk_free_per_period = risk_free_rate / CalculatorBase.TRADING_DAYS_PER_YEAR
+                dts = BasicDataApi().get_trading_day_list(start_date=sr.index[0], end_date=sr.index[-1]).datetime
+                sr_annual_vol = sr.reindex(dts).ffill()
+                sr_ret_annual_vol = sr_annual_vol.pct_change(1).iloc[1:]
             elif frequency == '1W':
                 period_1m = 4
                 period_3m = period_1m * 3
@@ -393,7 +397,7 @@ class CalculatorBase:
             cumu_ret = last_unit_nav - 1
             trade_year = days / CalculatorBase.TOTAL_DAYS_PER_YEAR
             annual_ret = math.pow(last_unit_nav, CalculatorBase.TOTAL_DAYS_PER_YEAR/days) - 1
-            annual_vol = sr_ret.std(ddof=1) * np.sqrt(period_1y)
+            annual_vol = sr_ret_annual_vol.std(ddof=1) * np.sqrt(period_1y)
             _begin_date = sr.index[0]
             recent_ret_res = CalculatorBase.calc_recent_ret(dates=dates,values=values,frequency='1D')
             recent_year_ret = recent_ret_res['recent_natural_year_ret']
@@ -447,6 +451,7 @@ class CalculatorBase:
                 assert len(dates) == len(benchmark_values), 'date and bench_values has different numbers'
                 sr_benchmark = pd.Series(benchmark_values, index=dates).sort_index().dropna()
                 sr_benchmark = sr_benchmark.set_axis(pd.to_datetime(sr_benchmark.index), inplace=False).resample(frequency).last().dropna()
+                total_relative_ret = sr.iloc[-1]/ sr.iloc[0] - sr_benchmark.iloc[-1] / sr_benchmark.iloc[0]
                 sr_benchmark.index = [i.date() for i in sr_benchmark.index]
                 if ret_method == 'log_ret':
                     sr_benchmark_ret = np.log(sr_benchmark).diff(1).iloc[1:]
@@ -603,6 +608,7 @@ class CalculatorBase:
                     'excess_mdd_date1':excess_mdd_date1,
                     'excess_mdd_date2':excess_mdd_date2,
                     'excess_mdd_lens':excess_mdd_lens,
+                    'total_relative_ret':total_relative_ret,
                 }
             else:
                 return {
@@ -720,6 +726,7 @@ class CalculatorBase:
                     'excess_mdd_date1':dates[0] if len(dates) > 0 else None,
                     'excess_mdd_date2':dates[0] if len(dates) > 0 else None,
                     'excess_mdd_lens':0,
+                    'total_relative_ret':0,
                 }
 
     @staticmethod
